
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "nm-connection.h" */

GType nm_connection_serialization_flags_get_type (void);
#define NM_TYPE_CONNECTION_SERIALIZATION_FLAGS (nm_connection_serialization_flags_get_type())

/* enumerations from "nm-dbus-interface.h" */

GType nm_version_info_capability_get_type (void);
#define NM_TYPE_VERSION_INFO_CAPABILITY (nm_version_info_capability_get_type())

GType nm_capability_get_type (void);
#define NM_TYPE_CAPABILITY (nm_capability_get_type())

GType nm_state_get_type (void);
#define NM_TYPE_STATE (nm_state_get_type())

GType nm_connectivity_state_get_type (void);
#define NM_TYPE_CONNECTIVITY_STATE (nm_connectivity_state_get_type())

GType nm_device_type_get_type (void);
#define NM_TYPE_DEVICE_TYPE (nm_device_type_get_type())

GType nm_device_capabilities_get_type (void);
#define NM_TYPE_DEVICE_CAPABILITIES (nm_device_capabilities_get_type())

GType nm_device_wifi_capabilities_get_type (void);
#define NM_TYPE_DEVICE_WIFI_CAPABILITIES (nm_device_wifi_capabilities_get_type())

GType nm_802_11_ap_flags_get_type (void);
#define NM_TYPE_802_11_AP_FLAGS (nm_802_11_ap_flags_get_type())

GType nm_802_11_ap_security_flags_get_type (void);
#define NM_TYPE_802_11_AP_SECURITY_FLAGS (nm_802_11_ap_security_flags_get_type())

GType nm_802_11_mode_get_type (void);
#define NM_TYPE_802_11_MODE (nm_802_11_mode_get_type())

GType nm_bluetooth_capabilities_get_type (void);
#define NM_TYPE_BLUETOOTH_CAPABILITIES (nm_bluetooth_capabilities_get_type())

GType nm_device_modem_capabilities_get_type (void);
#define NM_TYPE_DEVICE_MODEM_CAPABILITIES (nm_device_modem_capabilities_get_type())

GType nm_wimax_nsp_network_type_get_type (void);
#define NM_TYPE_WIMAX_NSP_NETWORK_TYPE (nm_wimax_nsp_network_type_get_type())

GType nm_device_state_get_type (void);
#define NM_TYPE_DEVICE_STATE (nm_device_state_get_type())

GType nm_device_state_reason_get_type (void);
#define NM_TYPE_DEVICE_STATE_REASON (nm_device_state_reason_get_type())

GType nm_metered_get_type (void);
#define NM_TYPE_METERED (nm_metered_get_type())

GType nm_connection_multi_connect_get_type (void);
#define NM_TYPE_CONNECTION_MULTI_CONNECT (nm_connection_multi_connect_get_type())

GType nm_active_connection_state_get_type (void);
#define NM_TYPE_ACTIVE_CONNECTION_STATE (nm_active_connection_state_get_type())

GType nm_active_connection_state_reason_get_type (void);
#define NM_TYPE_ACTIVE_CONNECTION_STATE_REASON (nm_active_connection_state_reason_get_type())

GType nm_secret_agent_get_secrets_flags_get_type (void);
#define NM_TYPE_SECRET_AGENT_GET_SECRETS_FLAGS (nm_secret_agent_get_secrets_flags_get_type())

GType nm_secret_agent_capabilities_get_type (void);
#define NM_TYPE_SECRET_AGENT_CAPABILITIES (nm_secret_agent_capabilities_get_type())

GType nm_ip_tunnel_mode_get_type (void);
#define NM_TYPE_IP_TUNNEL_MODE (nm_ip_tunnel_mode_get_type())

GType nm_checkpoint_create_flags_get_type (void);
#define NM_TYPE_CHECKPOINT_CREATE_FLAGS (nm_checkpoint_create_flags_get_type())

GType nm_settings_connection_flags_get_type (void);
#define NM_TYPE_SETTINGS_CONNECTION_FLAGS (nm_settings_connection_flags_get_type())

GType nm_activation_state_flags_get_type (void);
#define NM_TYPE_ACTIVATION_STATE_FLAGS (nm_activation_state_flags_get_type())

GType nm_settings_add_connection2_flags_get_type (void);
#define NM_TYPE_SETTINGS_ADD_CONNECTION2_FLAGS (nm_settings_add_connection2_flags_get_type())

GType nm_settings_update2_flags_get_type (void);
#define NM_TYPE_SETTINGS_UPDATE2_FLAGS (nm_settings_update2_flags_get_type())

GType nm_device_reapply_flags_get_type (void);
#define NM_TYPE_DEVICE_REAPPLY_FLAGS (nm_device_reapply_flags_get_type())

GType nm_device_managed_get_type (void);
#define NM_TYPE_DEVICE_MANAGED (nm_device_managed_get_type())

GType nm_device_managed_flags_get_type (void);
#define NM_TYPE_DEVICE_MANAGED_FLAGS (nm_device_managed_flags_get_type())

GType nm_ternary_get_type (void);
#define NM_TYPE_TERNARY (nm_ternary_get_type())

GType nm_manager_reload_flags_get_type (void);
#define NM_TYPE_MANAGER_RELOAD_FLAGS (nm_manager_reload_flags_get_type())

GType nm_device_interface_flags_get_type (void);
#define NM_TYPE_DEVICE_INTERFACE_FLAGS (nm_device_interface_flags_get_type())

GType nm_client_permission_get_type (void);
#define NM_TYPE_CLIENT_PERMISSION (nm_client_permission_get_type())

GType nm_client_permission_result_get_type (void);
#define NM_TYPE_CLIENT_PERMISSION_RESULT (nm_client_permission_result_get_type())

GType nm_radio_flags_get_type (void);
#define NM_TYPE_RADIO_FLAGS (nm_radio_flags_get_type())

GType nm_mptcp_flags_get_type (void);
#define NM_TYPE_MPTCP_FLAGS (nm_mptcp_flags_get_type())

/* enumerations from "nm-errors.h" */

GType nm_agent_manager_error_get_type (void);
#define NM_TYPE_AGENT_MANAGER_ERROR (nm_agent_manager_error_get_type())

GType nm_connection_error_get_type (void);
#define NM_TYPE_CONNECTION_ERROR (nm_connection_error_get_type())

GType nm_crypto_error_get_type (void);
#define NM_TYPE_CRYPTO_ERROR (nm_crypto_error_get_type())

GType nm_device_error_get_type (void);
#define NM_TYPE_DEVICE_ERROR (nm_device_error_get_type())

GType nm_manager_error_get_type (void);
#define NM_TYPE_MANAGER_ERROR (nm_manager_error_get_type())

GType nm_secret_agent_error_get_type (void);
#define NM_TYPE_SECRET_AGENT_ERROR (nm_secret_agent_error_get_type())

GType nm_settings_error_get_type (void);
#define NM_TYPE_SETTINGS_ERROR (nm_settings_error_get_type())

GType nm_vpn_plugin_error_get_type (void);
#define NM_TYPE_VPN_PLUGIN_ERROR (nm_vpn_plugin_error_get_type())

/* enumerations from "nm-keyfile.h" */

GType nm_keyfile_handler_flags_get_type (void);
#define NM_TYPE_KEYFILE_HANDLER_FLAGS (nm_keyfile_handler_flags_get_type())

GType nm_keyfile_handler_type_get_type (void);
#define NM_TYPE_KEYFILE_HANDLER_TYPE (nm_keyfile_handler_type_get_type())

GType nm_keyfile_warn_severity_get_type (void);
#define NM_TYPE_KEYFILE_WARN_SEVERITY (nm_keyfile_warn_severity_get_type())

/* enumerations from "nm-setting-8021x.h" */

GType nm_setting_802_1x_ck_format_get_type (void);
#define NM_TYPE_SETTING_802_1X_CK_FORMAT (nm_setting_802_1x_ck_format_get_type())

GType nm_setting_802_1x_ck_scheme_get_type (void);
#define NM_TYPE_SETTING_802_1X_CK_SCHEME (nm_setting_802_1x_ck_scheme_get_type())

GType nm_setting_802_1x_auth_flags_get_type (void);
#define NM_TYPE_SETTING_802_1X_AUTH_FLAGS (nm_setting_802_1x_auth_flags_get_type())

/* enumerations from "nm-setting-connection.h" */

GType nm_setting_connection_autoconnect_slaves_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_AUTOCONNECT_SLAVES (nm_setting_connection_autoconnect_slaves_get_type())

GType nm_setting_connection_lldp_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_LLDP (nm_setting_connection_lldp_get_type())

GType nm_setting_connection_mdns_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_MDNS (nm_setting_connection_mdns_get_type())

GType nm_setting_connection_llmnr_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_LLMNR (nm_setting_connection_llmnr_get_type())

GType nm_setting_connection_dns_over_tls_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_DNS_OVER_TLS (nm_setting_connection_dns_over_tls_get_type())

GType nm_setting_connection_dnssec_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_DNSSEC (nm_setting_connection_dnssec_get_type())

GType nm_setting_connection_down_on_poweroff_get_type (void);
#define NM_TYPE_SETTING_CONNECTION_DOWN_ON_POWEROFF (nm_setting_connection_down_on_poweroff_get_type())

/* enumerations from "nm-setting-dcb.h" */

GType nm_setting_dcb_flags_get_type (void);
#define NM_TYPE_SETTING_DCB_FLAGS (nm_setting_dcb_flags_get_type())

/* enumerations from "nm-setting-ethtool.h" */

GType nm_setting_ethtool_fec_mode_get_type (void);
#define NM_TYPE_SETTING_ETHTOOL_FEC_MODE (nm_setting_ethtool_fec_mode_get_type())

/* enumerations from "nm-setting-geneve.h" */

GType nm_setting_geneve_df_get_type (void);
#define NM_TYPE_SETTING_GENEVE_DF (nm_setting_geneve_df_get_type())

/* enumerations from "nm-setting-hsr.h" */

GType nm_setting_hsr_protocol_version_get_type (void);
#define NM_TYPE_SETTING_HSR_PROTOCOL_VERSION (nm_setting_hsr_protocol_version_get_type())

/* enumerations from "nm-setting-ip-config.h" */

GType nm_ip_address_cmp_flags_get_type (void);
#define NM_TYPE_IP_ADDRESS_CMP_FLAGS (nm_ip_address_cmp_flags_get_type())

GType nm_setting_ip_config_routed_dns_get_type (void);
#define NM_TYPE_SETTING_IP_CONFIG_ROUTED_DNS (nm_setting_ip_config_routed_dns_get_type())

GType nm_setting_ip_config_forwarding_get_type (void);
#define NM_TYPE_SETTING_IP_CONFIG_FORWARDING (nm_setting_ip_config_forwarding_get_type())

GType nm_ip_routing_rule_as_string_flags_get_type (void);
#define NM_TYPE_IP_ROUTING_RULE_AS_STRING_FLAGS (nm_ip_routing_rule_as_string_flags_get_type())

GType nm_dhcp_hostname_flags_get_type (void);
#define NM_TYPE_DHCP_HOSTNAME_FLAGS (nm_dhcp_hostname_flags_get_type())

/* enumerations from "nm-setting-ip-tunnel.h" */

GType nm_ip_tunnel_flags_get_type (void);
#define NM_TYPE_IP_TUNNEL_FLAGS (nm_ip_tunnel_flags_get_type())

/* enumerations from "nm-setting-ip4-config.h" */

GType nm_setting_ip4_link_local_get_type (void);
#define NM_TYPE_SETTING_IP4_LINK_LOCAL (nm_setting_ip4_link_local_get_type())

GType nm_setting_ip4_dhcp_ipv6_only_preferred_get_type (void);
#define NM_TYPE_SETTING_IP4_DHCP_IPV6_ONLY_PREFERRED (nm_setting_ip4_dhcp_ipv6_only_preferred_get_type())

/* enumerations from "nm-setting-ip6-config.h" */

GType nm_setting_ip6_config_privacy_get_type (void);
#define NM_TYPE_SETTING_IP6_CONFIG_PRIVACY (nm_setting_ip6_config_privacy_get_type())

GType nm_setting_ip6_config_addr_gen_mode_get_type (void);
#define NM_TYPE_SETTING_IP6_CONFIG_ADDR_GEN_MODE (nm_setting_ip6_config_addr_gen_mode_get_type())

/* enumerations from "nm-setting-ipvlan.h" */

GType nm_setting_ipvlan_mode_get_type (void);
#define NM_TYPE_SETTING_IPVLAN_MODE (nm_setting_ipvlan_mode_get_type())

/* enumerations from "nm-setting-macsec.h" */

GType nm_setting_macsec_mode_get_type (void);
#define NM_TYPE_SETTING_MACSEC_MODE (nm_setting_macsec_mode_get_type())

GType nm_setting_macsec_validation_get_type (void);
#define NM_TYPE_SETTING_MACSEC_VALIDATION (nm_setting_macsec_validation_get_type())

GType nm_setting_macsec_offload_get_type (void);
#define NM_TYPE_SETTING_MACSEC_OFFLOAD (nm_setting_macsec_offload_get_type())

/* enumerations from "nm-setting-macvlan.h" */

GType nm_setting_macvlan_mode_get_type (void);
#define NM_TYPE_SETTING_MACVLAN_MODE (nm_setting_macvlan_mode_get_type())

/* enumerations from "nm-setting-ovs-dpdk.h" */

GType nm_setting_ovs_dpdk_lsc_interrupt_get_type (void);
#define NM_TYPE_SETTING_OVS_DPDK_LSC_INTERRUPT (nm_setting_ovs_dpdk_lsc_interrupt_get_type())

/* enumerations from "nm-setting-proxy.h" */

GType nm_setting_proxy_method_get_type (void);
#define NM_TYPE_SETTING_PROXY_METHOD (nm_setting_proxy_method_get_type())

/* enumerations from "nm-setting-serial.h" */

GType nm_setting_serial_parity_get_type (void);
#define NM_TYPE_SETTING_SERIAL_PARITY (nm_setting_serial_parity_get_type())

/* enumerations from "nm-setting-sriov.h" */

GType nm_sriov_vf_vlan_protocol_get_type (void);
#define NM_TYPE_SRIOV_VF_VLAN_PROTOCOL (nm_sriov_vf_vlan_protocol_get_type())

GType nm_sriov_preserve_on_down_get_type (void);
#define NM_TYPE_SRIOV_PRESERVE_ON_DOWN (nm_sriov_preserve_on_down_get_type())

GType nm_sriov_eswitch_mode_get_type (void);
#define NM_TYPE_SRIOV_ESWITCH_MODE (nm_sriov_eswitch_mode_get_type())

GType nm_sriov_eswitch_inline_mode_get_type (void);
#define NM_TYPE_SRIOV_ESWITCH_INLINE_MODE (nm_sriov_eswitch_inline_mode_get_type())

GType nm_sriov_eswitch_encap_mode_get_type (void);
#define NM_TYPE_SRIOV_ESWITCH_ENCAP_MODE (nm_sriov_eswitch_encap_mode_get_type())

/* enumerations from "nm-setting-team.h" */

GType nm_team_link_watcher_arp_ping_flags_get_type (void);
#define NM_TYPE_TEAM_LINK_WATCHER_ARP_PING_FLAGS (nm_team_link_watcher_arp_ping_flags_get_type())

/* enumerations from "nm-setting-tun.h" */

GType nm_setting_tun_mode_get_type (void);
#define NM_TYPE_SETTING_TUN_MODE (nm_setting_tun_mode_get_type())

/* enumerations from "nm-setting-vlan.h" */

GType nm_vlan_priority_map_get_type (void);
#define NM_TYPE_VLAN_PRIORITY_MAP (nm_vlan_priority_map_get_type())

GType nm_vlan_flags_get_type (void);
#define NM_TYPE_VLAN_FLAGS (nm_vlan_flags_get_type())

/* enumerations from "nm-setting-wired.h" */

GType nm_setting_wired_wake_on_lan_get_type (void);
#define NM_TYPE_SETTING_WIRED_WAKE_ON_LAN (nm_setting_wired_wake_on_lan_get_type())

/* enumerations from "nm-setting-wireless-security.h" */

GType nm_wep_key_type_get_type (void);
#define NM_TYPE_WEP_KEY_TYPE (nm_wep_key_type_get_type())

GType nm_setting_wireless_security_pmf_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_SECURITY_PMF (nm_setting_wireless_security_pmf_get_type())

GType nm_setting_wireless_security_wps_method_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_SECURITY_WPS_METHOD (nm_setting_wireless_security_wps_method_get_type())

GType nm_setting_wireless_security_fils_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_SECURITY_FILS (nm_setting_wireless_security_fils_get_type())

/* enumerations from "nm-setting-wireless.h" */

GType nm_setting_wireless_wake_on_wlan_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_WAKE_ON_WLAN (nm_setting_wireless_wake_on_wlan_get_type())

GType nm_setting_wireless_powersave_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_POWERSAVE (nm_setting_wireless_powersave_get_type())

GType nm_setting_wireless_channel_width_get_type (void);
#define NM_TYPE_SETTING_WIRELESS_CHANNEL_WIDTH (nm_setting_wireless_channel_width_get_type())

/* enumerations from "nm-setting.h" */

GType nm_setting_secret_flags_get_type (void);
#define NM_TYPE_SETTING_SECRET_FLAGS (nm_setting_secret_flags_get_type())

GType nm_setting_compare_flags_get_type (void);
#define NM_TYPE_SETTING_COMPARE_FLAGS (nm_setting_compare_flags_get_type())

GType nm_setting_mac_randomization_get_type (void);
#define NM_TYPE_SETTING_MAC_RANDOMIZATION (nm_setting_mac_randomization_get_type())

GType nm_setting_diff_result_get_type (void);
#define NM_TYPE_SETTING_DIFF_RESULT (nm_setting_diff_result_get_type())

/* enumerations from "nm-utils.h" */

GType nm_utils_security_type_get_type (void);
#define NM_TYPE_UTILS_SECURITY_TYPE (nm_utils_security_type_get_type())

/* enumerations from "nm-vpn-dbus-interface.h" */

GType nm_vpn_service_state_get_type (void);
#define NM_TYPE_VPN_SERVICE_STATE (nm_vpn_service_state_get_type())

GType nm_vpn_connection_state_get_type (void);
#define NM_TYPE_VPN_CONNECTION_STATE (nm_vpn_connection_state_get_type())

GType nm_vpn_connection_state_reason_get_type (void);
#define NM_TYPE_VPN_CONNECTION_STATE_REASON (nm_vpn_connection_state_reason_get_type())

GType nm_vpn_plugin_failure_get_type (void);
#define NM_TYPE_VPN_PLUGIN_FAILURE (nm_vpn_plugin_failure_get_type())

/* enumerations from "nm-vpn-editor-plugin.h" */

GType nm_vpn_editor_plugin_capability_get_type (void);
#define NM_TYPE_VPN_EDITOR_PLUGIN_CAPABILITY (nm_vpn_editor_plugin_capability_get_type())

G_END_DECLS

/* Generated data ends here */

