
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __NM_ENUM_TYPES_H__
#define __NM_ENUM_TYPES_H__

#include "nm-core-enum-types.h"
#
#include <glib-object.h>

G_BEGIN_DECLS
GType nm_client_instance_flags_get_type (void) G_GNUC_CONST;
#define NM_TYPE_CLIENT_INSTANCE_FLAGS (nm_client_instance_flags_get_type ())
GType nm_client_error_get_type (void) G_GNUC_CONST;
#define NM_TYPE_CLIENT_ERROR (nm_client_error_get_type ())
G_END_DECLS

#endif /* __NM_ENUM_TYPES_H__ */

/* Generated data ends here */

